import { CookieService } from 'ngx-cookie-service';
import { DomSanitizer } from '@angular/platform-browser';
import { Injectable, Component, Input, NgModule, defineInjectable, inject } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClient, HttpClientModule } from '@angular/common/http';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EtherpadClientService {
    /**
     * @param {?} http
     * @param {?} cookie
     */
    constructor(http, cookie) {
        this.http = http;
        this.cookie = cookie;
        this.apiRoot = '';
        this.apiKey = '';
    }
    /**
     * @param {?} settings
     * @return {?}
     */
    connect(settings) {
        this.apiRoot = settings.host + ':' + settings.port + '/';
        this.apiKey = settings.apikey;
    }
    /**
     * @param {?} username
     * @param {?} userId
     * @param {?} meetingId
     * @param {?} meetingName
     * @return {?}
     */
    getDocSession(username, userId, meetingId, meetingName) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.createAuthorIfNotExistsFor(username, userId)
                .then((/**
             * @param {?} auther
             * @return {?}
             */
            (auther) => {
                console.log("auither", auther);
                /** @type {?} */
                let autherId = auther.data.authorID;
                this.createGroupIfNotExistsFor(meetingId)
                    .then((/**
                 * @param {?} group
                 * @return {?}
                 */
                (group) => {
                    /** @type {?} */
                    let groupId = group.data.groupID;
                    this.listPads(groupId)
                        .then((/**
                     * @param {?} pads
                     * @return {?}
                     */
                    (pads) => {
                        if (pads.data.padIDs.length == 0) {
                            this.createGroupPad(groupId, meetingName)
                                .then((/**
                             * @param {?} pad
                             * @return {?}
                             */
                            (pad) => {
                                this.createSession(groupId, autherId)
                                    .then((/**
                                 * @param {?} session
                                 * @return {?}
                                 */
                                (session) => {
                                    /** @type {?} */
                                    let date = new Date();
                                    /** @type {?} */
                                    let exp = date.setHours(date.getHours() + 24);
                                    this.cookie.set('sessionID', session.data.sessionID, exp, '/');
                                    resolve({
                                        padId: pad.data.padID,
                                        sessionID: session.data.sessionID
                                    });
                                }));
                            }));
                        }
                        else {
                            this.createSession(groupId, autherId)
                                .then((/**
                             * @param {?} session
                             * @return {?}
                             */
                            (session) => {
                                resolve({
                                    padId: pads.data.padIDs[0],
                                    sessionID: session.data.sessionID
                                });
                            }));
                        }
                    }));
                }));
            }));
        }));
    }
    /*
       * Auther methods
       */
    /**
     * @param {?} name
     * @return {?}
     */
    createAuther(name) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createAuthor?apikey=' + this.apiKey + '&name=' + name)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} name
     * @param {?} userId
     * @return {?}
     */
    createAuthorIfNotExistsFor(name, userId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createAuthorIfNotExistsFor?apikey=' + this.apiKey + '&name=' + name + '&authorMapper=' + userId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} authorID
     * @return {?}
     */
    listPadsOfAuthor(authorID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/listPadsOfAuthor?apikey=' + this.apiKey + '&authorID=' + authorID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} authorID
     * @return {?}
     */
    getAuthorName(authorID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.1/getAuthorName?apikey=' + this.apiKey + '&authorID=' + authorID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /*
       * Group methods
       */
    /**
     * @param {?} meetingId
     * @return {?}
     */
    createGroup(meetingId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createGroup?apikey=' + this.apiKey)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} meetingId
     * @return {?}
     */
    createGroupIfNotExistsFor(meetingId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createGroup?apikey=' + this.apiKey)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} groupID
     * @return {?}
     */
    deleteGroup(groupID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createGroup?apikey=' + this.apiKey + '&groupID=' + groupID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} groupID
     * @return {?}
     */
    listPads(groupID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/listPads?apikey=' + this.apiKey + '&groupID=' + groupID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} groupID
     * @param {?} padName
     * @param {?=} padText
     * @return {?}
     */
    createGroupPad(groupID, padName, padText = '') {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createGroupPad?apikey=' + this.apiKey + '&groupID=' + groupID + '&padName=' + padName + '&text=' + padText)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @return {?}
     */
    listAllGroups() {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.1/listPads?apikey=' + this.apiKey)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /*
       * Session methods
       */
    /**
     * @param {?} groupID
     * @param {?} authorID
     * @return {?}
     */
    createSession(groupID, authorID) {
        /** @type {?} */
        let currentDate = new Date();
        currentDate.setHours(currentDate.getHours() + 24);
        /** @type {?} */
        let validUntil = currentDate.getTime() / 1000;
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/api/1/createSession?apikey=' + this.apiKey + '&groupID=' + groupID + '&authorID=' + authorID + '&validUntil=' + validUntil)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0) {
                    /** @type {?} */
                    let date = new Date();
                    /** @type {?} */
                    let exp = date.setHours(date.getHours() + 24);
                    this.cookie.set('sessionID', res.data.sessionID, exp, '/');
                    resolve(res);
                }
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} sessionId
     * @return {?}
     */
    deleteSession(sessionId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/deleteSession?apikey=' + this.apiKey + '&sessionID=' + sessionId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} sessionId
     * @return {?}
     */
    getSessionInfo(sessionId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/api/1/getSessionInfo?apikey=' + this.apiKey + '&sessionID=' + sessionId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} groupID
     * @return {?}
     */
    listSessionsOfGroup(groupID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/listSessionsOfGroup?apikey=' + this.apiKey + '&groupID=' + groupID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} authorID
     * @return {?}
     */
    listSessionsOfAuthor(authorID) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/listSessionsOfAuthor?apikey=' + this.apiKey + '&authorID=' + authorID)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /*
       * Pad methods
       */
    /**
     * @param {?} padId
     * @param {?=} text
     * @return {?}
     */
    createPad(padId, text = '') {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/createPad?apikey=' + this.apiKey + '&padID=' + padId + '&text=' + text)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    getRevisionsCount(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/getRevisionsCount?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    getSavedRevisionsCount(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.2.11/getSavedRevisionsCount?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    listSavedRevisions(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.2.11/listSavedRevisions?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @param {?} rev
     * @return {?}
     */
    saveRevision(padId, rev) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.2.11/saveRevision?apikey=' + this.apiKey + '&padID=' + padId + '&rev=' + rev)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    padUsersCount(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/padUsersCount?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    padUsers(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.1/padUsers?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    deletePad(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/padUsers?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @return {?}
     */
    listAllPads() {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1.2.1/listAllPads?apikey=' + this.apiKey)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
    /**
     * @param {?} padId
     * @return {?}
     */
    getReadOnlyID(padId) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.http.get(this.apiRoot + 'api/1/getReadOnlyID?apikey=' + this.apiKey + '&padID=' + padId)
                .subscribe((/**
             * @param {?} res
             * @return {?}
             */
            (res) => {
                if (res.code == 0)
                    resolve(res);
                else
                    reject(res);
            }));
        }));
    }
}
EtherpadClientService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
EtherpadClientService.ctorParameters = () => [
    { type: HttpClient },
    { type: CookieService }
];
/** @nocollapse */ EtherpadClientService.ngInjectableDef = defineInjectable({ factory: function EtherpadClientService_Factory() { return new EtherpadClientService(inject(HttpClient), inject(CookieService)); }, token: EtherpadClientService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EtherpadClientComponent {
    /**
     * @param {?} etherPadService
     * @param {?} sanitizer
     */
    constructor(etherPadService, sanitizer) {
        this.etherPadService = etherPadService;
        this.sanitizer = sanitizer;
        this.host = '';
        this.enablePad = false;
        this.loader = true;
        this.host = this.etherPadService.apiRoot;
        if (!this.chat)
            this.chat = false;
        this.etherPadService.getDocSession(this.username, this.userId, this.groupId, this.groupName)
            .then((/**
         * @param {?} res
         * @return {?}
         */
        (res) => {
            this.url = this.sanitizer.bypassSecurityTrustResourceUrl(`${this.host}p/${res.padId}?showChat=${this.chat}&userName=${this.username}`);
            this.enablePad = true;
            this.loader = false;
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
EtherpadClientComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-etherpad-client',
                template: `
  <iframe *ngIf="enablePad" [src]="url" class="sharedDoc" referrerpolicy="same-origin"></iframe>
  <div *ngIf="loader" class="sharedDoc"></div>
  `,
                styles: [`
  .sharedDoc{
    position: absolute;
    z-index: 5;
    top: -5px;
    margin: 5px auto;
    width: calc(100% - 296px);
    height: calc(100% - 50px);
    background-color: #ffffff
    }
  `]
            }] }
];
/** @nocollapse */
EtherpadClientComponent.ctorParameters = () => [
    { type: EtherpadClientService },
    { type: DomSanitizer }
];
EtherpadClientComponent.propDecorators = {
    chat: [{ type: Input, args: ['chat',] }],
    username: [{ type: Input, args: ['username',] }],
    userId: [{ type: Input, args: ['userId',] }],
    groupId: [{ type: Input, args: ['groupId',] }],
    groupName: [{ type: Input, args: ['groupName',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EtherpadClientModule {
}
EtherpadClientModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EtherpadClientComponent],
                imports: [
                    CommonModule,
                    HttpClientModule
                ],
                exports: [EtherpadClientComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { EtherpadClientService, EtherpadClientComponent, EtherpadClientModule };

//# sourceMappingURL=etherpad-client.js.map